@@ -1,7 +1,6 @@
-from .dockontext import container_generator_from_image
-from .dockontext import Result
+from .dockontext import Result, container_generator_from_image
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 __all__ = [
     "container_generator_from_dockerfile",
